@@ -17,11 +17,9 @@ Textile's procedural code into a class framework
 Additions and fixes Copyright (c) 2006 Alex Shiels http://thresholdstate.com/
 
 """
-
 import uuid
-import six
-from six.moves.urllib_parse import (urlparse, urlsplit, urlunsplit, quote,
-        unquote)
+from urllib.parse import urlparse, urlsplit, urlunsplit, quote, unquote
+from collections import OrderedDict
 
 from textile.tools import sanitizer, imagesize
 from textile.regex_strings import (align_re_s, cls_re_s, pnct_re_s,
@@ -31,10 +29,6 @@ from textile.utils import (decode_high, encode_high, encode_html, generate_tag,
         parse_attributes, pba)
 from textile.objects import Block, Table
 
-
-from collections import OrderedDict
-
-
 try:
     import regex as re
 except ImportError:
@@ -46,7 +40,7 @@ class Textile(object):
     unrestricted_url_schemes = restricted_url_schemes + ('file', 'tel',
             'callto', 'sftp', 'data')
 
-    btag = ('bq', 'bc', 'notextile', 'pre', 'h[1-6]', 'fn\d+', 'p', '###')
+    btag = ('bq', 'bc', 'notextile', 'pre', 'h[1-6]', r'fn\d+', 'p', '###')
     btag_lite = ('bq', 'bc', 'p')
 
     note_index = 1
@@ -170,7 +164,6 @@ class Textile(object):
                     regex_snippets['space'], 'abr': regex_snippets['abr'],
                     'nab': regex_snippets['nab'], 'pnct': pnct_re_s}), re.U),
         ]
-
         # These are the changes that need to be made for characters that occur
         # at the beginning of the string.
         self.glyph_search_initial = list(self.glyph_search)
@@ -259,7 +252,6 @@ class Textile(object):
 
         if not self.lite:
             text = self.placeNoteLists(text)
-
         text = self.retrieve(text)
         text = text.replace('{0}:glyph:'.format(self.uid), '')
 
@@ -327,7 +319,7 @@ class Textile(object):
 
                 # does the first line of this ol have a start attribute
                 if len(tl) > len(pt):
-                    # no, set it to 1
+                    # no, set it to 1.
                     if start is None:
                         self.olstarts[tl] = 1
                     # yes, set it to the given number
@@ -352,8 +344,8 @@ class Textile(object):
                     except KeyError:
                         self.olstarts[tl] = 1
 
-            nm = re.match("^(?P<nextlistitem>[#\*;:]+)(_|[\d]+)?{0}"
-                    "[ .].*".format(cls_re_s), nextline)
+            nm = re.match(r"^(?P<nextlistitem>[#\*;:]+)(_|[\d]+)?{0}"
+                    r"[ .].*".format(cls_re_s), nextline)
             if nm:
                 nl = nm.group('nextlistitem')
 
@@ -363,12 +355,11 @@ class Textile(object):
             if ';' in pt and ':' in tl:
                 ls[tl] = 2
 
-            atts = pba(atts)
+            atts = pba(atts, restricted=self.restricted)
             tabs = '\t' * len(tl)
-            # If start is still None, set it to '', else leave the value
-            # that we've already formatted.
+            # If start is still None, set it to '', else leave the value that
+            # we've already formatted.
             start = start or ''
-
             # if this item tag isn't in the list, create a new list and
             # item, else just create the item
             if tl not in ls:
@@ -380,7 +371,6 @@ class Textile(object):
                 line = ("\t<{0}{1}>{2}".format(litem, atts, content) if
                         showitem else '')
             line = '{0}{1}'.format(tabs, line)
-
             if len(nl) <= len(tl):
                 if showitem:
                     line = "{0}</{1}>".format(line, litem)
@@ -393,14 +383,12 @@ class Textile(object):
                     if len(k) > 1 and v != 2:
                         line = "{0}</{1}>".format(line, litem)
                     del ls[k]
-
-            # Remember the current Textile tag
+            # Remember the current Textile tag:
             pt = tl
-
             # This else exists in the original php version.  I'm not sure how
             # to come up with a case where the line would not match.  I think
             # it may have been necessary due to the way php returns matches.
-            #else:
+            # else:
                 #line = "{0}\n".format(line)
             result.append(line)
         return self.doTagBr(litem, "\n".join(result))
@@ -424,13 +412,12 @@ class Textile(object):
             tre = '|'.join(self.btag)
         else:
             tre = '|'.join(self.btag_lite)
-
         # split the text by two or more newlines, retaining the newlines in the
         # split list
         text = re.split(r'(\n{2,})', text)
 
         # some blocks, when processed, will ask us to output nothing, if that's
-        # the case, we'd want to drop the whitespace which comes after it.
+        # the case, we'd want to drop the whitespace which follows it.
         eat_whitespace = False
 
         # check to see if previous block has already been escaped
@@ -498,7 +485,7 @@ class Textile(object):
             # no tag specified
             else:
                 # if we're inside an extended block, add the text from the
-                # previous line to the front
+                # previous line to the front.
                 if ext and out:
                     if block.tag == 'p':
                         line = generate_tag(block.tag, line, block.outer_atts)
@@ -535,7 +522,6 @@ class Textile(object):
                 multiline_para = True
             else:
                 line = self.doPBr(line)
-
             if not block.tag == 'p':
                 multiline_para = False
 
@@ -561,8 +547,8 @@ class Textile(object):
             if block.eat:
                 eat_whitespace = True
 
-        # at this point, we've gone through all the lines, and if there's still
-        # an extension in effect, we close it here.
+        # at this point, we've gone through all the lines. if there's still an
+        # extension in effect, we close it here
         if ext and out and not block.tag == 'p':
             block.content = out.pop()
             block.process()
@@ -727,7 +713,7 @@ class Textile(object):
                 linkparts = []
                 i = 0
 
-                while balanced is not 0 or i is 0: # pragma: no branch
+                while balanced != 0 or i == 0: # pragma: no branch
                     # Starting at the end, pop off the previous part of the
                     # slice's fragments.
 
@@ -750,7 +736,7 @@ class Textile(object):
                         # HAL!"":url...  In this case we count a zero length in
                         # the last position as a closing quote and others as
                         # opening quotes.
-                        if i is 0:
+                        if i == 0:
                             balanced = balanced + 1
                         else:
                             balanced = balanced - 1
@@ -765,7 +751,7 @@ class Textile(object):
                             break
                         # If the next possibility is empty or ends in a space
                         # we have a closing ".
-                        if (possibility is '' or possibility.endswith(' ')):
+                        if (possibility == '' or possibility.endswith(' ')):
                             # force search exit
                             balanced = 0;
 
@@ -843,7 +829,7 @@ class Textile(object):
         # "text":url?q[]=x][123]    will have "[123]" popped off the back, the
         # remaining closing square brackets will later be tested for balance
         if (counts[']']):
-            m = re.search('(?P<url>^.*\])(?P<tight>\[.*?)$', url, flags=re.U)
+            m = re.search(r'(?P<url>^.*\])(?P<tight>\[.*?)$', url, flags=re.U)
             if m:
                 url, tight = m.groups()
 
@@ -961,13 +947,13 @@ class Textile(object):
         text = self.span(text)
         text = self.glyphs(text)
         url = self.shelveURL(self.encode_url(urlunsplit(uri_parts)))
-        attributes = parse_attributes(atts)
+        attributes = parse_attributes(atts, restricted=self.restricted)
+        attributes['href'] = url
         if title:
             # if the title contains unicode data, it is annoying to get Python
             # 2.6 and all the latter versions working properly.  But shelving
             # the title is a quick and dirty solution.
             attributes['title'] = self.shelve(title)
-        attributes['href'] = url
         if self.rel:
             attributes['rel'] = self.rel
         a_text = generate_tag('a', text, attributes)
@@ -985,10 +971,6 @@ class Textile(object):
         Fixed version of the following code fragment from Stack Overflow:
             http://stackoverflow.com/a/804380/72656
         """
-        # turn string into unicode
-        if not isinstance(url, six.text_type):
-            url = url.decode('utf8')
-
         # parse it
         parsed = urlsplit(url)
 
@@ -1017,12 +999,8 @@ class Textile(object):
         # slashes, and this is a way to clean that up. It branches for PY2/3
         # because the quote and unquote functions expects different input
         # types: unicode strings for PY2 and str for PY3.
-        if six.PY2:
-            path_parts = (quote(unquote(pce.encode('utf8')), b'') for pce in
-                    parsed.path.split('/'))
-        else:
-            path_parts = (quote(unquote(pce), b'') for pce in
-                    parsed.path.split('/'))
+        path_parts = (quote(unquote(pce), b'') for pce in
+                parsed.path.split('/'))
         path = '/'.join(path_parts)
 
         # put it back together
@@ -1078,7 +1056,7 @@ class Textile(object):
         }
 
         tag = qtags[tag]
-        atts = pba(atts)
+        atts = pba(atts, restricted=self.restricted)
         if cite:
             atts = '{0} cite="{1}"'.format(atts, cite.rstrip())
 
@@ -1128,14 +1106,14 @@ class Textile(object):
             atts.update(align=alignments[align])
         atts.update(alt=title)
         if size:
-            atts.update(height=six.text_type(size[1]))
+            atts.update(height="{0}".format(size[1]))
         atts.update(src=url)
         if attributes:
-            atts.update(parse_attributes(attributes))
+            atts.update(parse_attributes(attributes, restricted=self.restricted))
         if title:
             atts.update(title=title)
         if size:
-            atts.update(width=six.text_type(size[0]))
+            atts.update(width="{0}".format(size[0]))
         img = generate_tag('img', ' /', atts)
         if href:
             a_atts = OrderedDict(href=href)
@@ -1220,7 +1198,7 @@ class Textile(object):
             atts, content = m.groups()
             # cleanup
             content = content.strip()
-            atts = pba(atts)
+            atts = pba(atts, restricted=self.restricted)
 
             # split the content into the term and definition
             xm = re.match(r'^(.*?)[\s]*:=(.*?)[\s]*(=:|:=)?[\s]*$', content,
@@ -1269,8 +1247,8 @@ class Textile(object):
                 # sort o by key
                 o = OrderedDict(sorted(o.items(), key=lambda t: t[0]))
             self.notes = o
-        text_re = re.compile('<p>notelist({0})(?:\:([\w|{1}]))?([\^!]?)(\+?)'
-                '\.?[\s]*</p>'.format(cls_re_s, syms_re_s), re.U)
+        text_re = re.compile(r'<p>notelist({0})(?:\:([\w|{1}]))?([\^!]?)(\+?)'
+                r'\.?[\s]*</p>'.format(cls_re_s, syms_re_s), re.U)
         text = text_re.sub(self.fNoteLists, text)
         return text
 
@@ -1306,7 +1284,7 @@ class Textile(object):
                     o.append(li)
             self.notelist_cache[index] = "\n".join(o)
             result = self.notelist_cache[index]
-        list_atts = pba(att)
+        list_atts = pba(att, restricted=self.restricted)
         result = '<ol{0}>\n{1}\n\t</ol>'.format(list_atts, result)
         return result
 
@@ -1351,7 +1329,7 @@ class Textile(object):
 
         # Ignores subsequent defs using the same label
         if 'def' not in self.notes[label]: # pragma: no branch
-            self.notes[label]['def'] = {'atts': pba(att), 'content':
+            self.notes[label]['def'] = {'atts': pba(att, restricted=self.restricted), 'content':
                     self.graf(content), 'link': link}
         return ''
 
@@ -1373,7 +1351,7 @@ class Textile(object):
         processed into the notes array. So now we can resolve the link numbers
         in the order we process the refs..."""
         atts, label, nolink = match.groups()
-        atts = pba(atts)
+        atts = pba(atts, restricted=self.restricted)
         nolink = nolink == '!'
 
         # Assign a sequence number to this reference if there isn't one already
@@ -1420,7 +1398,7 @@ class Textile(object):
 
     def retrieveURL(self, match):
         url = self.refCache.get(int(match.group('token')), '')
-        if url is '':
+        if url == '':
             return url
 
         if url in self.urlrefs:
